#!/bin/bash -eu
shopt -s extglob

## Local service deployment script
#
# Creates the directory where systemd anticipates unit files, if necessary.
# Deploys the service file and reloads the systemd user daemon.
# Deploys all other artifacts to a clean deployment subdirectory of the home directory.
# Runs further deployment logic, if implemented.
# Restarts the deployed service.

service_base_name="pseuco-jani-server"
service_name="${service_base_name}.service"
service_file="${service_name}"
service_files_directory="${HOME}/.config/systemd/user/"
artifacts_directory="${HOME}/artifacts-${service_base_name}"
deployment_directory="${HOME}/deployment-${service_base_name}"

echo "Stopping service..."
if systemctl --user status "${service_name}" &>/dev/null
then
  systemctl --user stop "${service_name}"
fi

echo "Deploying service file..."
mkdir -p "${service_files_directory}"
cp "${artifacts_directory}/${service_file}" "${service_files_directory}/"
systemctl --user daemon-reload

echo "Deploying artifacts..."
rm -rf "${deployment_directory}"
mkdir "${deployment_directory}"
cp -R "${artifacts_directory}"/!(${service_file}|systemd-deploy.sh) "${deployment_directory}/"

ln -s "${HOME}/certificates" "${deployment_directory}/"
cp "${HOME}/pvts" "${deployment_directory}/"

echo "Starting service..."
systemctl --user start "${service_name}"

echo "Done."
